@@ -2,10 +2,10 @@ use strict;
 use warnings;
 package YAML::PP::Lexer;
 
-our $VERSION = '0.006_003'; # TRIAL VERSION
+our $VERSION = '0.007_001'; # TRIAL VERSION
 
-use constant TRACE => $ENV{YAML_PP_TRACE};
-use constant DEBUG => $ENV{YAML_PP_DEBUG} || $ENV{YAML_PP_TRACE};
+use constant TRACE => $ENV{YAML_PP_TRACE} ? 1 : 0;
+use constant DEBUG => ($ENV{YAML_PP_DEBUG} || $ENV{YAML_PP_TRACE}) ? 1 : 0;
 
 use YAML::PP::Grammar qw/ $GRAMMAR /;
 use Carp qw/ croak /;
