@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP::Loader;
 
-our $VERSION = '0.006_003'; # TRIAL VERSION
+our $VERSION = '0.007_001'; # TRIAL VERSION
 
 use YAML::PP::Parser;
 use YAML::PP::Constructor;
@@ -13,7 +13,7 @@ sub new {
     my ($class, %args) = @_;
 
     my $cyclic_refs = delete $args{cyclic_refs} || 'allow';
-    my $schema = delete $args{schema} // YAML::PP->default_schema(
+    my $schema = delete $args{schema} || YAML::PP->default_schema(
         boolean => 'perl',
     );
 
