@@ -3,10 +3,10 @@ use strict;
 use warnings;
 package YAML::PP::Parser;
 
-our $VERSION = '0.006_003'; # TRIAL VERSION
+our $VERSION = '0.007_001'; # TRIAL VERSION
 
-use constant TRACE => $ENV{YAML_PP_TRACE};
-use constant DEBUG => $ENV{YAML_PP_DEBUG} || $ENV{YAML_PP_TRACE};
+use constant TRACE => $ENV{YAML_PP_TRACE} ? 1 : 0;
+use constant DEBUG => ($ENV{YAML_PP_DEBUG} || $ENV{YAML_PP_TRACE}) ? 1 : 0;
 
 use YAML::PP::Render;
 use YAML::PP::Lexer;
@@ -126,6 +126,13 @@ sub parse_stream {
             last;
         }
 
+        if (@$next_tokens and $next_tokens->[0]->{name} eq 'DOC_END') {
+            if (not $start) {
+                $implicit = 0;
+                $self->parse_document_end($next_tokens);
+                next;
+            }
+        }
         $self->start_document(not $start);
 
         my $new_type = 'FULLNODE';
@@ -136,13 +143,7 @@ sub parse_stream {
 
         if (@$next_tokens and $next_tokens->[0]->{name} eq 'DOC_END') {
             $implicit = 0;
-            push @{ $self->tokens }, shift @$next_tokens;
-            if (@$next_tokens and $next_tokens->[0]->{name} eq 'EOL') {
-                push @{ $self->tokens }, shift @$next_tokens;
-            }
-            else {
-                $self->exception("Expected EOL");
-            }
+            $self->parse_document_end($next_tokens);
         }
         else {
             $implicit = 1;
@@ -216,6 +217,17 @@ sub parse_document_head {
     return ($start, $start_line);
 }
 
+sub parse_document_end {
+    my ($self, $next_tokens) = @_;
+    push @{ $self->tokens }, shift @$next_tokens;
+    if (@$next_tokens and $next_tokens->[0]->{name} eq 'EOL') {
+        push @{ $self->tokens }, shift @$next_tokens;
+    }
+    else {
+        $self->exception("Expected EOL after document end");
+    }
+}
+
 my %nodetypes = (
     MAPVALUE => 'NODETYPE_COMPLEX',
     MAP => 'NODETYPE_MAP',
@@ -821,7 +833,7 @@ sub event_to_test_suite {
             else {
                 $content = '';
             }
-            $string .= ' ' . $info->{style} . ($content // '');
+            $string .= ' ' . $info->{style} . $content;
         }
         elsif ($ev eq 'alias_event') {
             $string = "=ALI *$content";
@@ -859,8 +871,9 @@ sub debug_yaml {
 
 sub debug_next_line {
     my ($self) = @_;
-    my $next_line = $self->lexer->next_line // [];
-    my $line = $next_line->[0] // '';
+    my $next_line = $self->lexer->next_line || [];
+    my $line = $next_line->[0];
+    $line = '' unless defined $line;
     $line =~ s/( +)$/'·' x length $1/e;
     $line =~ s/\t/▸/g;
     $self->note("NEXT LINE: >>$line<<");
